@@ -314,7 +314,8 @@ public class Babase {
                 .executeQuery("SELECT sname, rank FROM ranks WHERE grp = "
                         + rid.group.toSQLLiteral() + " AND rnktype = "
                         + rid.rankType.toSQLLiteral() + " AND rnkdate = "
-                        + dateToSQLLiteral(rid.startDate));
+                        + dateToSQLLiteral(rid.startDate)
+                        + " ORDER BY ranks.rank");
         Vector<String> snames = new Vector<String>();
         Vector<Integer> ranks = new Vector<Integer>();
         while (rs.next()) {
