@@ -18,8 +18,8 @@ public class AboutUI extends JFrame {
         setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
 
         JTextArea textArea = new JTextArea();
-        textArea.append("Babase Ranker v1.1\n");
-        textArea.append("v1.1 by Karl O. Pinc <kop@meme.com>\n");
+        textArea.append("Babase Ranker v1.2\n");
+        textArea.append("v1.1, v1.2 by Karl O. Pinc <kop@meme.com>\n");
         textArea.append("v1.0 by Jun Yang\n");
         textArea.append("v0.9 by Tyler Brock and Jun Yang\n");
         textArea.append("Initial Java version by Jun Yang\n");
